@@ -6,7 +6,7 @@ from time import sleep
 
 
 def signal_handle(signum, frame):
-    print "\nUser interrupt.\n"
+    print("\nUser interrupt.\n")
     sys.exit(1)
 
 
